
#include "yodl.h"

void
gram_WARNING ()
{
  char
   *msg;			/* message to print */
  int
    oldwarnflag;		/* previous warning flag */

  msg = gram_parlist (builtin_get (idx_WARNING), 0);

  message (3, "%s %s\n", builtin_get (idx_WARNING), str_short (msg));

  oldwarnflag = flags.warn;	/* save old warning flag */
  flags.warn = 1;		/* make sure warnings printed */
  gram_warn ("input parsing", msg);	/* output message */
  flags.warn = oldwarnflag;	/* restore warning level */
}
